@@ -37,6 +37,14 @@ except NameError:
 # by default reject any keys with <2048 bits (see #45).
 _KEY_SIZE = 2048
 
+# Default certificate expiry date:
+# OpenSSL on Windows fails if you try to give it a date after
+# ~3001-01-19:
+#   https://github.com/pyca/cryptography/issues/3194
+# Some versions of cryptography on 32-bit platforms fail if you give
+# them dates after ~2038-01-19:
+#   https://github.com/pyca/cryptography/pull/4658
+DEFAULT_EXPIRY = datetime.datetime(2038, 1, 1)
 
 def _name(name, organization_name=None, common_name=None):
     name_pieces = [
@@ -61,20 +69,15 @@ def _smells_like_pyopenssl(ctx):
     return getattr(ctx, "__module__", "").startswith("OpenSSL")
 
 
-def _cert_builder_common(subject, issuer, public_key):
+def _cert_builder_common(subject, issuer, public_key, not_after=None):
+    not_after = not_after if not_after else DEFAULT_EXPIRY
     return (
         x509.CertificateBuilder()
         .subject_name(subject)
         .issuer_name(issuer)
         .public_key(public_key)
         .not_valid_before(datetime.datetime(2000, 1, 1))
-        # OpenSSL on Windows fails if you try to give it a date after
-        # ~3001-01-19:
-        #   https://github.com/pyca/cryptography/issues/3194
-        # Some versions of cryptography on 32-bit platforms fail if you give
-        # them dates after ~2038-01-19:
-        #   https://github.com/pyca/cryptography/pull/4658
-        .not_valid_after(datetime.datetime(2038, 1, 1))
+        .not_valid_after(not_after)
         .serial_number(x509.random_serial_number())
         .add_extension(
             x509.SubjectKeyIdentifier.from_public_key(public_key),
@@ -237,25 +240,17 @@ class CA(object):
             )
             .add_extension(
                 x509.KeyUsage(
-                    digital_signature=False,
+                    digital_signature=True,  # OCSP
                     content_commitment=False,
                     key_encipherment=False,
                     data_encipherment=False,
                     key_agreement=False,
-                    key_cert_sign=True,
-                    crl_sign=True,
+                    key_cert_sign=True,  # sign certs
+                    crl_sign=True,  # sign revocation lists
                     encipher_only=False,
                     decipher_only=False),
                 critical=True
             )
-            .add_extension(
-                x509.ExtendedKeyUsage([
-                    ExtendedKeyUsageOID.CLIENT_AUTH,
-                    ExtendedKeyUsageOID.SERVER_AUTH,
-                    ExtendedKeyUsageOID.CODE_SIGNING,
-                ]),
-                critical=True
-            )
             .sign(
                 private_key=sign_key,
                 algorithm=hashes.SHA256(),
@@ -298,7 +293,7 @@ class CA(object):
 
     def issue_cert(self, *identities, **kwargs):
         """issue_cert(*identities, common_name=None, organization_name=None, \
-        organization_unit_name=None)
+        organization_unit_name=None, not_after=None)
 
         Issues a certificate. The certificate can be used for either servers
         or clients.
@@ -339,6 +334,9 @@ class CA(object):
           organization_unit_name: Sets the "Organization Unit Name" (OU)
             attribute on the certificate. By default, a random one will be
             generated.
+        
+          not_after: Set the expiry date (notAfter) of the certificate. This
+            argument type is `datetime.datetime`.
 
         Returns:
           LeafCert: the newly-generated certificate.
@@ -347,6 +345,7 @@ class CA(object):
         common_name = kwargs.pop("common_name", None)
         organization_name = kwargs.pop("organization_name", None)
         organization_unit_name = kwargs.pop("organization_unit_name", None)
+        not_after = kwargs.pop("not_after", None)
         if kwargs:
             raise TypeError("unrecognized keyword arguments {}".format(kwargs))
 
@@ -382,6 +381,7 @@ class CA(object):
                 ),
                 self._certificate.subject,
                 key.public_key(),
+                not_after=not_after,
             )
             .add_extension(
                 x509.BasicConstraints(ca=False, path_length=None),
@@ -394,6 +394,27 @@ class CA(object):
                 ),
                 critical=True,
             )
+            .add_extension(
+                x509.KeyUsage(
+                    digital_signature=True,
+                    content_commitment=False,
+                    key_encipherment=True,
+                    data_encipherment=False,
+                    key_agreement=False,
+                    key_cert_sign=False,
+                    crl_sign=False,
+                    encipher_only=False,
+                    decipher_only=False),
+                critical=True
+            )
+            .add_extension(
+                x509.ExtendedKeyUsage([
+                    ExtendedKeyUsageOID.CLIENT_AUTH,
+                    ExtendedKeyUsageOID.SERVER_AUTH,
+                    ExtendedKeyUsageOID.CODE_SIGNING,
+                ]),
+                critical=True
+            )
             .sign(
                 private_key=self._private_key,
                 algorithm=hashes.SHA256(),
